const urlParams = new URLSearchParams(window.location.search);
const box = urlParams.get("box");

const menuButton = document.querySelector(".menu-button");

window.addEventListener("DOMContentLoaded", () => {
    document.querySelector(".box-name").innerText = box;

    if (!box) {
        document.querySelector(".box-select-wrapper").classList.remove("hidden");
        document.querySelectorAll("button").forEach(el => el.disabled = true);
    }

    getBoxes();
})

menuButton.addEventListener("click", () => {
    document.querySelector(".box-select-wrapper").classList.toggle("hidden");

});

const switchBox = (e) => {
    console.log(e.value);
    urlParams.set("box", e.value);
    window.location.search = urlParams;
}

const populateBoxes = (boxes) => {
    const select = document.getElementById("box-select");
    Object.keys(boxes).forEach(curr => {
        const el = document.createElement("option");
        el.value = curr;
        el.innerText = curr;
        if (curr == box) {
            el.selected = true;
        }
        select.appendChild(el);
    });
}

const getBoxes = () => {
    fetch("/boxes")
    .then(res => res.json())
    .then(data => {
        if (!data.success) {
            console.log("Something went wrong...")
            console.error(data)
            alert("Something went wrong.")
            return;
        }

        populateBoxes(data.boxes)
    })
    .catch((err) => {
        console.log("Something went wrong...")
        console.error(err)
        alert("Something went wrong.")
        return;
    })
}

const sendCommand = (cmd) => {
    console.log(cmd)
    fetch("/control/"+ box, {method: "POST", headers: {"Content-Type": "application/json"}, body: JSON.stringify({ command: cmd })})
    .then((res) => res.json())
    .then(data => {
        if (!data.success) {
            console.log("Something went wrong...")
            console.error(data)
            alert("Something went wrong.")
            return;
        }

        console.log("Executed command.")
    })
    .catch((err) => {
        console.log("Something went wrong...")
        console.error(err)
        alert("Something went wrong.")
        return;
    })
}